# Generated by Django 3.1.4 on 2020-12-28 15:40

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('jet', '0002_delete_userdashboardmodule'),
    ]

    operations = [
        migrations.AlterField(
            model_name='pinnedapplication',
            name='user',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL, verbose_name='user'),
        ),
    ]
