{% load i18n %}
<h3>{% blocktranslate with filter_title=title %} {{ filter_title }} {% endblocktranslate %}</h3>
<ul>
	{% for choice in choices %}
		<li{% if choice.selected %} class="selected"{% endif %}>
			<a href="{{ choice.query_string|iriencode }}" title="{{ choice.display }}">{{ choice.display }}</a></li>
	{% endfor %}
</ul>